This library interfaces with the Metdley API. 

Metdley offers a seamless solution for generating accurate metadata for music catalogs. Eliminating the hassle of manual data entry, saving you time and ensuring your catalog is ready for seamless distribution.

Read more at: docs.metdley.com
